==> bloodhound_7.5.1.orig.tar.gz: BloodHound-7.5.1/packages/javascript/bh-shared-ui/src/components/HelpTexts/AZAvereContributor/Abuse.tsx <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

import { Link, Typography } from '@mui/material';
import { FC } from 'react';

const Abuse: FC = () => {
    return (
        <>
            <Typography variant='body2'>
                The Avere Contributor role allows you to run SYSTEM commands on the VM
            </Typography>

            <Typography variant='body2'>Via PowerZure:</Typography>
            <Link target='_blank' rel='noopener' href='http://Invoke-AzureRunCommand'>
                Invoke-AzureRunCommand
            </Link>
            <br />
            <Link target='_blank' rel='noopener' href='http://Invoke-AzureRunMSBuild'>
                Invoke-AzureRunMSBuild
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener'
                href='https://powerzure.readthedocs.io/en/latest/Functions/operational.html#invoke-azurerunprogram'>
                Invoke-AzureRunProgram
            </Link>
        </>
    );
};

export default Abuse;

==> bloodhound_8.3.1.orig.tar.gz: BloodHound-8.3.1/packages/javascript/bh-shared-ui/src/components/HelpTexts/AZAvereContributor/Abuse.tsx <==
// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

import { Link, Typography } from '@mui/material';
import { FC } from 'react';

const Abuse: FC = () => {
    return (
        <>
            <Typography variant='body2'>
                The Avere Contributor role allows you to run SYSTEM commands on the VM
            </Typography>

            <Typography variant='body2'>Via PowerZure:</Typography>
            <Link target='_blank' rel='noopener noreferrer' href='http://Invoke-AzureRunCommand'>
                Invoke-AzureRunCommand
            </Link>
            <br />
            <Link target='_blank' rel='noopener noreferrer' href='http://Invoke-AzureRunMSBuild'>
                Invoke-AzureRunMSBuild
            </Link>
            <br />
            <Link
                target='_blank'
                rel='noopener noreferrer'
                href='https://powerzure.readthedocs.io/en/latest/Functions/operational.html#invoke-azurerunprogram'>
                Invoke-AzureRunProgram
            </Link>
        </>
    );
};

export default Abuse;
